@@ -3,14 +3,19 @@ from __future__ import annotations
 
 import json
 import shutil
+import subprocess
+from importlib.metadata import version
 from pathlib import Path
 from typing import Any, Dict, Optional
 
-import requests
+import httpx
+import yaml
 from jinja2 import Environment, PackageLoader
 
 from .openapi_parser import OpenAPI, import_string_from_reference
 
+__version__ = version(__package__)
+
 
 def _get_project_for_url_or_path(url: Optional[str], path: Optional[Path]) -> _Project:
     data_dict = _get_json(url=url, path=path)
@@ -18,6 +23,17 @@ def _get_project_for_url_or_path(url: Optional[str], path: Optional[Path]) -> _P
     return _Project(openapi=openapi)
 
 
+def load_config(*, path: Path) -> None:
+    """ Loads config from provided Path """
+    config_data = yaml.safe_load(path.read_text())
+
+    if "class_overrides" in config_data:
+        from .openapi_parser import reference
+
+        for class_name, class_data in config_data["class_overrides"].items():
+            reference.class_overrides[class_name] = reference.Reference(**class_data)
+
+
 def create_new_client(*, url: Optional[str], path: Optional[Path]) -> None:
     """ Generate the client library """
     project = _get_project_for_url_or_path(url=url, path=path)
@@ -35,7 +51,7 @@ def _get_json(*, url: Optional[str], path: Optional[Path]) -> Dict[str, Any]:
     if url is not None and path is not None:
         raise ValueError("Provide URL or Path, not both.")
     elif url is not None:
-        response = requests.get(url)
+        response = httpx.get(url)
         json_bytes = response.content
     elif path is not None:
         json_bytes = path.read_bytes()
@@ -65,6 +81,7 @@ class _Project:
         self._build_metadata()
         self._build_models()
         self._build_api()
+        self._reformat()
 
     def update(self) -> None:
         """ Update an existing project """
@@ -76,6 +93,11 @@ class _Project:
         self._create_package()
         self._build_models()
         self._build_api()
+        self._reformat()
+
+    def _reformat(self) -> None:
+        subprocess.run("isort --recursive --apply", cwd=self.project_dir, shell=True)
+        subprocess.run("black .", cwd=self.project_dir, shell=True)
 
     def _create_package(self) -> None:
         self.package_dir.mkdir()
@@ -107,6 +129,11 @@ class _Project:
             )
         )
 
+        # .gitignore
+        git_ignore_path = self.project_dir / ".gitignore"
+        git_ignore_template = self.env.get_template(".gitignore")
+        git_ignore_path.write_text(git_ignore_template.render())
+
     def _build_models(self) -> None:
         # Generate models
         models_dir = self.package_dir / "models"
@@ -140,13 +167,21 @@ class _Project:
         api_dir = self.package_dir / "api"
         api_dir.mkdir()
         api_init = api_dir / "__init__.py"
-        api_init.write_text('""" Contains all methods for accessing the API """')
+        api_init.write_text('""" Contains synchronous methods for accessing the API """')
 
-        api_errors = api_dir / "errors.py"
+        async_api_dir = self.package_dir / "async_api"
+        async_api_dir.mkdir()
+        async_api_init = async_api_dir / "__init__.py"
+        async_api_init.write_text('""" Contains async methods for accessing the API """')
+
+        api_errors = self.package_dir / "errors.py"
         errors_template = self.env.get_template("errors.pyi")
         api_errors.write_text(errors_template.render())
 
         endpoint_template = self.env.get_template("endpoint_module.pyi")
+        async_endpoint_template = self.env.get_template("async_endpoint_module.pyi")
         for tag, collection in self.openapi.endpoint_collections_by_tag.items():
             module_path = api_dir / f"{tag}.py"
             module_path.write_text(endpoint_template.render(collection=collection))
+            async_module_path = async_api_dir / f"{tag}.py"
+            async_module_path.write_text(async_endpoint_template.render(collection=collection))
